"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var fs_extra_1 = __importDefault(require("fs-extra"));
var chalk_1 = __importDefault(require("chalk"));
var utils_1 = require("./utils");
var templates_1 = require("./templates");
var actions_1 = require("./actions");
var log = console.log, error = console.error;
var generateComponentTemplate = function (componentName, args) {
    var withStyle = args.withStyle, useTypescript = args.useTypescript;
    var files = [];
    var ComponentMain = utils_1.getDataBasedOnCondition(useTypescript, templates_1.ComponetTsFunction, templates_1.ComponetJsFunction);
    var templates = [
        actions_1.getMainTemplate(ComponentMain, componentName, args),
        actions_1.getIndexTemplate(templates_1.ComponetIndex, componentName, args),
    ];
    if (withStyle) {
        templates.push(actions_1.getStyleTemplate(templates_1.ComponetStyle, componentName, args));
    }
    templates.forEach(function (t) {
        files.push({
            template: utils_1.transform(t.template, t.transform),
            fileName: t.fileName
        });
    });
    return files;
};
var generateComponent = function (componentName, args) {
    var pathDir = args.path;
    var componentTemplate = generateComponentTemplate(componentName, args);
    try {
        fs_extra_1.default.emptyDirSync(path_1.default.join(pathDir, componentName));
        componentTemplate.forEach(function (component) {
            fs_extra_1.default.writeFileSync(path_1.default.join(pathDir, componentName, component.fileName), component.template);
        });
        log(chalk_1.default.cyan("Component " + chalk_1.default.cyan.bold(componentName) + " was created"));
    }
    catch (e) {
        error(chalk_1.default.red(e));
        process.exit(1);
    }
};
exports.default = generateComponent;
